@@ -17,11 +17,11 @@ Module::Starter::Simple - a simple, comprehensive Module::Starter plugin
 
 =head1 VERSION
 
-Version 1.72
+Version 1.73
 
 =cut
 
-our $VERSION = '1.72';
+our $VERSION = '1.73';
 
 =head1 SYNOPSIS
 
@@ -113,7 +113,7 @@ sub create_distro {
     $self->{license_record} = $self->_license_record();
 
     $self->{main_module} = $modules[0];
-    if ( not $self->{distro} ) {
+    if ( not defined $self->{distro} or not length $self->{distro} ) {
         $self->{distro} = $self->{main_module};
         $self->{distro} =~ s/::/-/g;
     }
@@ -1212,7 +1212,7 @@ EOH
     $module_boilerplate_tests .=
       "  module_boilerplate_ok('".$self->_module_to_pm_file($_)."');\n" for @modules;
 
-    my $boilerplate_tests = @modules + 2 + $[;
+    my $boilerplate_tests = @modules + 2;
     $xt_files{'boilerplate.t'} = $header.<<"HERE";
 plan tests => $boilerplate_tests;
 
@@ -1722,7 +1722,7 @@ You can find documentation for this module with the perldoc command.
 ];
     my @reference_links = _reference_links();
 
-    return unless @reference_links;
+    return undef unless @reference_links;
     $content .= qq[
 
 You can also look for information at:
